@@ -19,7 +19,7 @@ with 'Data::Object::Role::Stashable';
 
 use DBI;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 # ATTRIBUTES
 
@@ -32,7 +32,7 @@ has 'dbh' => (
 fun new_dbh($self) {
   DBI->connect($self->dsn, $self->username, $self->password, {
     RaiseError => 1,
-    AutoCommit => 0
+    AutoCommit => 1
   })
 }
 
@@ -78,6 +78,29 @@ has 'password' => (
 
 # METHODS
 
+method clone(Str $source) {
+  my $initial = $self->initial;
+
+  my $dbh = DBI->connect($self->dsngen($initial),
+    $self->username,
+    $self->password,
+    {
+      RaiseError => 1,
+      AutoCommit => 1
+    }
+  );
+
+  my $sth = $dbh->prepare(qq(CREATE DATABASE "@{[$self->database]}" TEMPLATE "$source"));
+
+  $sth->execute;
+  $dbh->disconnect;
+
+  $self->dbh;
+  $self->immutable;
+
+  return $self;
+}
+
 method create() {
   my $initial = $self->initial;
 
@@ -260,6 +283,26 @@ This package implements the following methods:
 
 =cut
 
+=head2 clone
+
+  clone(Str $source) : Object
+
+The clone method creates a temporary database from a database template.
+
+=over 4
+
+=item clone example #1
+
+  # given: synopsis
+
+  $tdbi->clone('template0');
+
+  # <Test::DB::Postgres>
+
+=back
+
+=cut
+
 =head2 create
 
   create() : Object
