@@ -18,10 +18,11 @@ with 'Data::Object::Role::Immutable';
 with 'Data::Object::Role::Stashable';
 
 use DBI;
+use File::Copy ();
 use File::Spec ();
 use File::Temp ();
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 # ATTRIBUTES
 
@@ -32,7 +33,7 @@ has 'dbh' => (
 );
 
 fun new_dbh($self) {
-  DBI->connect($self->dsn, '', '', { RaiseError => 1, AutoCommit => 0 })
+  DBI->connect($self->dsn, '', '', { RaiseError => 1, AutoCommit => 1 })
 }
 
 has 'dsn' => (
@@ -57,6 +58,12 @@ fun new_file($self) {
 
 # METHODS
 
+method clone(Str $source) {
+  File::Copy::copy($source, $self->file);
+
+  return $self->create;
+}
+
 method create() {
   my $dbh = $self->dbh;
 
@@ -178,6 +185,26 @@ This package implements the following methods:
 
 =cut
 
+=head2 clone
+
+  clone(Str $source) : Object
+
+The clone method creates a temporary database from a database template.
+
+=over 4
+
+=item clone example #1
+
+  # given: synopsis
+
+  $tdbi->clone('source.db');
+
+  # <Test::DB::Sqlite>
+
+=back
+
+=cut
+
 =head2 create
 
   create() : Object
